==> Paws-0.34.tar.gz: Paws-0.34/lib/Paws/CognitoIdp/DescribeUserPoolClient.pm <==

package Paws::CognitoIdp::DescribeUserPoolClient;
  use Moose;
  has ClientId => (is => 'ro', isa => 'Str', required => 1);
  has UserPoolId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeUserPoolClient');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CognitoIdp::DescribeUserPoolClientResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CognitoIdp::DescribeUserPoolClient - Arguments for method DescribeUserPoolClient on Paws::CognitoIdp

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeUserPoolClient on the 
Amazon Cognito Identity Provider service. Use the attributes of this class
as arguments to method DescribeUserPoolClient.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeUserPoolClient.

As an example:

  $service_obj->DescribeUserPoolClient(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> ClientId => Str

The ID of the client associated with the user pool.



=head2 B<REQUIRED> UserPoolId => Str

The user pool ID for the user pool you want to describe.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeUserPoolClient in L<Paws::CognitoIdp>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.35.tar.gz: Paws-0.35/lib/Paws/CognitoIdp/DescribeUserPoolClient.pm <==

package Paws::CognitoIdp::DescribeUserPoolClient;
  use Moose;
  has ClientId => (is => 'ro', isa => 'Str', required => 1);
  has UserPoolId => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeUserPoolClient');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CognitoIdp::DescribeUserPoolClientResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CognitoIdp::DescribeUserPoolClient - Arguments for method DescribeUserPoolClient on Paws::CognitoIdp

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeUserPoolClient on the 
Amazon Cognito Identity Provider service. Use the attributes of this class
as arguments to method DescribeUserPoolClient.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeUserPoolClient.

As an example:

  $service_obj->DescribeUserPoolClient(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> ClientId => Str

The app client ID of the app associated with the user pool.



=head2 B<REQUIRED> UserPoolId => Str

The user pool ID for the user pool you want to describe.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeUserPoolClient in L<Paws::CognitoIdp>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
